@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2022-02-17 18:29:10
+@LastEditTime: 2022-03-01 17:02:49
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -56,6 +56,24 @@ class GetCrmIntegralHandler(TopBaseHandler):
         shop_member_integral = invoke_result_data.data
         return self.reponse_json_success(shop_member_integral)
 
+class GetIsMemberHandler(TopBaseHandler):
+    """
+    :description: 获取是否是店铺会员
+    """
+    @filter_check_params()
+    def get_async(self):
+        """
+        :description: 获取是否是店铺会员
+        :return: 是否是店铺会员
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_taobao_param().source_app_id
+        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
+        if app_info:
+            access_token = app_info.access_token
+        result = self.check_is_member(access_token)
+        return self.reponse_json_success(result)
+
 
 class SyncPayOrderHandler(TopBaseHandler):
     """
