@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2022-02-18 12:00:03
+@LastEditTime: 2022-03-08 15:25:34
 @LastEditors: HuangJianYi
 :description: App相关
 """
@@ -13,7 +13,7 @@ from seven_cloudapp.handlers.server.app_s import AppUpdateHandler
 from seven_cloudapp.handlers.server.app_s import AppInfoHandler
 
 from seven_cloudapp.models.db_models.base.base_info_model import *
-
+from seven_cloudapp.models.db_models.app.app_info_model import *
 
 class BaseInfoHandler(SevenBaseHandler):
     """
@@ -141,7 +141,10 @@ class CheckGmPowerHandler(SevenBaseHandler):
         store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
         if not store_user_nick:
             return self.reponse_json_success(is_power)
-        if store_user_nick == config.get_value("test_user_nick"):
+        app_info = AppInfoModel(context=self).get_entity("user_nick=%s", params=store_user_nick)
+        if not app_info:
+            is_power = False
+        if app_info.is_custom == 1:
             is_power = True
         return self.reponse_json_success(is_power)
 
@@ -163,7 +166,11 @@ class GetAppidByGmHandler(SevenBaseHandler):
         store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
         if not store_user_nick:
             return self.reponse_json_success(app_id)
-        if store_user_nick == config.get_value("test_user_nick"):
+        is_power = False
+        app_info = AppInfoModel(context=self).get_entity("user_nick=%s", params=store_user_nick)
+        if app_info and app_info.is_custom == 1:
+            is_power = True
+        if is_power == True:
             app_info_dict = AppInfoModel(context=self).get_dict("store_name=%s", field="app_id", params=[store_name])
             if app_info_dict:
                 app_id = app_info_dict["app_id"]
